==> haskell-dav-1.3.2-30-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-dav.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: DAV
version: 1.3.2
id: DAV-1.3.2-D5SUd0MIEU3Ao01uBkSubt
key: DAV-1.3.2-D5SUd0MIEU3Ao01uBkSubt
license: GPL-3
copyright: Copyright (C) 2012-2018  Clint Adams
maintainer: clint@debian.org
homepage: http://floss.scru.org/hDAV
synopsis: RFC 4918 WebDAV support
description:
    This is a library for the Web Distributed Authoring and Versioning
    (WebDAV) extensions to HTTP.  At present it supports a very small
    subset of client functionality.
    .
    In addition, there is an executable, hdav, which can be used for
    command-line operation.
category: Web
author: Clint Adams
exposed: True
indefinite: False
exposed-modules:
    Network.Protocol.HTTP.DAV
hidden-modules: Network.Protocol.HTTP.DAV.TH
abi: 81f14967ddecad6835c979c29a837f64
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/DAV-1.3.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/DAV-1.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/DAV-1.3.2
hs-libraries: HSDAV-1.3.2-D5SUd0MIEU3Ao01uBkSubt
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    case-insensitive-1.2.0.10-CVuHCqku7IOKRRWT8fztNw
    containers-0.5.10.2 data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr
    exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq
    http-client-0.5.10-Kkc0WJNViMILcFHCsDXTRS
    http-client-tls-0.3.5.3-3kXSepoFbkBCiiEnIGPVG5
    http-types-0.9.1-L0SXZjYb79NLj6p0SwccQX
    lens-4.15.4-81WesV5SaQU8mHfsXlwvGV transformers-0.5.2.0
    transformers-base-0.4.4-E8cVJ8zOMCQDdcbsfJzxdl
    transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
    xml-conduit-1.7.1.2-IA7b8ZbXsQv4e6rI1d34oq
    xml-hamlet-0.4.1.1-4gjeSMmUsM77KW4Nd7RMCZ
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             case-insensitive-1.2.0.10-CVuHCqku7IOKRRWT8fztNw=2ce96ef32b613c82da204b6eddca57f2
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr=0186e0f4b96bc201d2baef8ade597d90
             exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq=349f1b5172af08123dc6c444b05979b3
             http-client-0.5.10-Kkc0WJNViMILcFHCsDXTRS=5780a54d8149f1024c4b84b0db563ed7
             http-client-tls-0.3.5.3-3kXSepoFbkBCiiEnIGPVG5=63bab28bad345c3b354e60c276ffae1f
             http-types-0.9.1-L0SXZjYb79NLj6p0SwccQX=39fa7a400c896fb5d30c824d62823b68
             lens-4.15.4-81WesV5SaQU8mHfsXlwvGV=82abfc425102f60fc18da76ef0099869
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             transformers-base-0.4.4-E8cVJ8zOMCQDdcbsfJzxdl=34c1d6b33f33105a74600f465b68cb2b
             transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM=506de314acc216de1ce76634db1785eb
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
             xml-conduit-1.7.1.2-IA7b8ZbXsQv4e6rI1d34oq=5c7ff00b7f2bafd89dd63b6c611805c1
             xml-hamlet-0.4.1.1-4gjeSMmUsM77KW4Nd7RMCZ=edbaa1f65a84acbd143078b48b5fac94
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
haddock-interfaces: /usr/share/doc/haskell-dav/html/DAV.haddock
haddock-html: /usr/share/doc/haskell-dav/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dav-1.3.2-35-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-dav.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: DAV
version: 1.3.2
id: DAV-1.3.2-Aa4MeuY51YoEkELRpKMHFe
key: DAV-1.3.2-Aa4MeuY51YoEkELRpKMHFe
license: GPL-3
copyright: Copyright (C) 2012-2018  Clint Adams
maintainer: clint@debian.org
homepage: http://floss.scru.org/hDAV
synopsis: RFC 4918 WebDAV support
description:
    This is a library for the Web Distributed Authoring and Versioning
    (WebDAV) extensions to HTTP.  At present it supports a very small
    subset of client functionality.
    .
    In addition, there is an executable, hdav, which can be used for
    command-line operation.
category: Web
author: Clint Adams
exposed: True
indefinite: False
exposed-modules:
    Network.Protocol.HTTP.DAV
hidden-modules: Network.Protocol.HTTP.DAV.TH
abi: fdede1a0a760b33351d030a3c320a8cc
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/DAV-1.3.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/DAV-1.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/DAV-1.3.2
hs-libraries: HSDAV-1.3.2-Aa4MeuY51YoEkELRpKMHFe
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-6moQBu1HxUPLo5Vi55MiZR
    containers-0.5.10.2 data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr
    exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq
    http-client-0.5.10-GdZhzxgFVd158ULfsa4ibS
    http-client-tls-0.3.5.3-5ZfnS64GyDW7XLxw9J3Jx
    http-types-0.9.1-I5VXdG5r7Fv5gm7UD4yo3B
    lens-4.15.4-81WesV5SaQU8mHfsXlwvGV transformers-0.5.2.0
    transformers-base-0.4.4-E8cVJ8zOMCQDdcbsfJzxdl
    transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
    xml-conduit-1.7.1.2-GCocRUuO79hGfSxswDpN3Q
    xml-hamlet-0.4.1.1-58atujpNjRT3RksDaMMdKW
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             case-insensitive-1.2.0.11-6moQBu1HxUPLo5Vi55MiZR=1c6594e3192e08eeeeb5e70e5d90ad4f
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr=0186e0f4b96bc201d2baef8ade597d90
             exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq=349f1b5172af08123dc6c444b05979b3
             http-client-0.5.10-GdZhzxgFVd158ULfsa4ibS=1a725e900d5aecda52da983428c7075d
             http-client-tls-0.3.5.3-5ZfnS64GyDW7XLxw9J3Jx=990df664be6ec2e78e7d27feb926c9a3
             http-types-0.9.1-I5VXdG5r7Fv5gm7UD4yo3B=1fabab8f133df5a739212b62b9cfb522
             lens-4.15.4-81WesV5SaQU8mHfsXlwvGV=82abfc425102f60fc18da76ef0099869
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             transformers-base-0.4.4-E8cVJ8zOMCQDdcbsfJzxdl=34c1d6b33f33105a74600f465b68cb2b
             transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM=506de314acc216de1ce76634db1785eb
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
             xml-conduit-1.7.1.2-GCocRUuO79hGfSxswDpN3Q=3a5403ebb0deb0c51fafad26f3cee1a2
             xml-hamlet-0.4.1.1-58atujpNjRT3RksDaMMdKW=c6b3bb8774f799b2b367b3056c12d9a7
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
haddock-interfaces: /usr/share/doc/haskell-dav/html/DAV.haddock
haddock-html: /usr/share/doc/haskell-dav/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
